@@ -57,33 +57,30 @@ ctStanParMatrices <- function(fit, parvalues, timeinterval=1, sf=NA){
 npars <- try(get_num_upars(sf),silent = TRUE) #$stanmodel)
 
 if(class(npars)=='try-error'){ #in case R has been restarted or similar
-  standataout <- fit$data
-  standataout<-unlist(standataout)
-  standataout[is.na(standataout)] <- 99999
-  standataout <- utils::relist(standataout,skeleton=fit$data)
-  suppressOutput(sf <- suppressWarnings(sampling(fit$stanmodel,data=standataout,iter=1,control=list(max_treedepth=1),chains=1)))
+  sf <- stan_reinitsf(fit$stanmodel,data=fit$standata) #suppressOutput(sf <- suppressWarnings(sampling(,iter=1,control=list(max_treedepth=1),chains=1)))
   npars <- get_num_upars(sf)
   pars <- c(parvalues,rep(0,npars - fit$data$nparams))
-  sf <- constrain_pars(sf, pars)
+  sfc <- constrain_pars(sf, pars)
 } else { #if no problem getting npars...
   pars <- c(parvalues,rep(0,npars - fit$data$nparams))
-  sf <- try(constrain_pars(sf, pars))
+  sfc <- try(constrain_pars(sf, pars))
 }
 
-for(m in fit$setup$basematrices){
-  assign(m,ctCollapse(sf[[paste0('pop_',m)]],1,mean))
+for(m in c(fit$setup$basematrices,'asymDIFFUSION')){
+  # assign(m,ctCollapse(sfc[[paste0('pop_',m)]],1,mean)) 
+  assign(m,sfc[[paste0('pop_',m)]]) 
 }
 
-choltrue <- !as.logical(fit$data$lineardynamics * fit$data$intoverstates)
+choltrue <- FALSE #!as.logical(fit$data$lineardynamics)
 
-if(choltrue) DIFFUSION = msquare(DIFFUSION) #sdcovchol2cov(DIFFUSION,0)
+# if(choltrue) DIFFUSION = msquare(DIFFUSION) #sdcovchol2cov(DIFFUSION,0)
 DIFFUSIONcor = suppressWarnings(stats::cov2cor(DIFFUSION))
 DIFFUSIONcor[is.na(DIFFUSIONcor)] <- 0
 
 
 
-DRIFTHATCH<-DRIFT %x% diag(nrow(DRIFT)) + diag(nrow(DRIFT)) %x% DRIFT
-asymDIFFUSION<-matrix(-solve(DRIFTHATCH, c(DIFFUSION)), nrow=nrow(DRIFT))
+# DRIFTHATCH<-DRIFT %x% diag(nrow(DRIFT)) + diag(nrow(DRIFT)) %x% DRIFT
+# asymDIFFUSION<-matrix(-solve(DRIFTHATCH, c(DIFFUSION)), nrow=nrow(DRIFT))
 asymDIFFUSIONcor = suppressWarnings(stats::cov2cor(asymDIFFUSION))
 asymDIFFUSIONcor[is.na(asymDIFFUSIONcor)] <- 0
 
@@ -114,7 +111,7 @@ asymCINT = -solve(DRIFT) %*% CINT
 
 
 
-if(choltrue) T0VAR=msquare(T0VAR)
+# if(choltrue) T0VAR=msquare(T0VAR)
 T0VARcor = suppressWarnings(stats::cov2cor(T0VAR))
 T0VARcor[is.na(T0VARcor)] <- 0
 dimnames(T0VAR)=list(ln,ln)
