@@ -127,11 +127,7 @@ ctStanTIpredeffects<-function(fit,returndifference=FALSE, probs=c(.025,.5,.975),
     npars <- try(get_num_upars(sf),silent=TRUE) #$stanmodel)
     
     if(class(npars)=='try-error'){ #in case R has been restarted or similar
-      standataout <- fit$data
-      standataout<-unlist(standataout)
-      standataout[is.na(standataout)] <- 99999
-      standataout <- utils::relist(standataout,skeleton=fit$data)
-      suppressOutput(sf <- suppressWarnings(sampling(fit$stanmodel,data=standataout,iter=1,control=list(max_treedepth=1),chains=1)))
+      sf <- stan_reinitsf(fit$stanmodel,fit$standata)
     }
 
     parmatlists<-lapply(1:nrow(rawpopmeans), function(x) { #for each param vector
